Attached

Struct Attached 

pub struct Attached { /* private fields */ }
A container that attaches elements to the top, bottom, left, or right of an inner element.

Uses absolute positioning and measures the attached element’s size to offset it correctly relative to the inner content.

Example

fn app() -> impl IntoElement {
    let mut open = use_state(|| false);

    Attached::new(
        Button::new()
            .on_press(move |_| open.toggle())
            .child("Toggle"),
    )
    .bottom()
    .maybe_child(open().then(|| label().text("Attached below!")))
}

Implementations

Source

impl Attached

pub fn new(inner: impl IntoElement) -> Attached

pub fn position(self, position: AttachedPosition) -> Attached

pub fn top(self) -> Attached

pub fn bottom(self) -> Attached

pub fn left(self) -> Attached

pub fn right(self) -> Attached