pub struct Card { /* private fields */ }Expand description
Implementations
Sourceimpl Card
impl Card
pub fn new() -> Card
Sourcepub fn get_layout_variant(&self) -> &CardLayoutVariant
pub fn get_layout_variant(&self) -> &CardLayoutVariant
Get the current layout variant.
Sourcepub fn get_theme_layout(&self) -> Option<&CardLayoutThemePartial>
pub fn get_theme_layout(&self) -> Option<&CardLayoutThemePartial>
Get the layout theme override.
Sourcepub fn style_variant(self, style_variant: impl Into<CardStyleVariant>) -> Card
pub fn style_variant(self, style_variant: impl Into<CardStyleVariant>) -> Card
Set the style variant.
Sourcepub fn layout_variant(
self,
layout_variant: impl Into<CardLayoutVariant>,
) -> Card
pub fn layout_variant( self, layout_variant: impl Into<CardLayoutVariant>, ) -> Card
Set the layout variant.
Sourcepub fn hoverable(self, hoverable: impl Into<bool>) -> Card
pub fn hoverable(self, hoverable: impl Into<bool>) -> Card
Set whether the card should respond to hover interactions.
Sourcepub fn on_press(
self,
on_press: impl Into<EventHandler<Event<PressEventData>>>,
) -> Card
pub fn on_press( self, on_press: impl Into<EventHandler<Event<PressEventData>>>, ) -> Card
Set the press event handler.
Sourcepub fn theme_colors(self, theme: CardColorsThemePartial) -> Card
pub fn theme_colors(self, theme: CardColorsThemePartial) -> Card
Set custom color theme.
Sourcepub fn theme_layout(self, theme: CardLayoutThemePartial) -> Card
pub fn theme_layout(self, theme: CardLayoutThemePartial) -> Card
Set custom layout theme.
Sourcepub fn filled(self) -> Card
pub fn filled(self) -> Card
Shortcut for Self::style_variant with CardStyleVariant::Filled.
Sourcepub fn outline(self) -> Card
pub fn outline(self) -> Card
Shortcut for Self::style_variant with CardStyleVariant::Outline.
Sourcepub fn compact(self) -> Card
pub fn compact(self) -> Card
Shortcut for Self::layout_variant with CardLayoutVariant::Compact.
Sourcepub fn cursor_icon(self, cursor_icon: impl Into<CursorIcon>) -> Card
pub fn cursor_icon(self, cursor_icon: impl Into<CursorIcon>) -> Card
Override the cursor icon shown when hovering over this component while hoverable.